# -*- coding:utf-8 -*-
import sys
import os
__author__ = 'allen yang'
__version__ = '0.1.1'
from wencai.core.event import (get_scrape_report,
                               set_variable,
                               get_strategy,
                               get_event_evaluate)